setClass("RPPA",
         representation = list(
           data="data.frame",
           file="character"
           ))

RPPA <- function(filename, path='.') {
  temp <- read.table(file.path(path, filename), fill=TRUE,
                     header=TRUE, row.names=NULL, sep='\t',
                     quote='', comment.char='', skip=4)
  temp <- temp[,1:(ncol(temp)-1)]
  newNames <- dimnames(temp)[[2]]
  newNames <- sub("GeneID",   "Sample",  newNames)
  newNames <- sub("mean\_",   "Mean.",   newNames)
  newNames <- sub("vol\_",    "Vol.",    newNames)
  newNames <- sub("median\_", "Median.", newNames)
  newNames <- sub("net",      "Net",     newNames)
  newNames <- sub("total",    "Total",   newNames)
  newNames <- sub("bkg",      "Bkg",     newNames)
  newNames <- sub("dust",     "Dust",    newNames)
  dimnames(temp)[[2]] <- newNames
  new("RPPA", data=temp, file = filename)
}

setMethod("summary", "RPPA", function(object, ...) {
  cat(paste("An RPPA object loaded from", object@file, "\n\n"))
  summary(object@data)
})

setMethod("image", "RPPA", function(x, measure="Mean.Net", main=measure,
                                    colorbar=FALSE,
                                    col=terrain.colors(256),
                                    ...) {
  temp <- x@data
  my <- max(temp$Main.Row) * max(temp$Sub.Row)
  mx <- max(temp$Main.Col) * max(temp$Sub.Col)
  yspot <- 1+my-(max(temp$Sub.Row)*(temp$Main.Row-1) + temp$Sub.Row)
  xspot <- max(temp$Sub.Col)*(temp$Main.Col-1) + temp$Sub.Col
  geo <- tapply(temp[,measure], list(xspot, yspot), mean)
  if (colorbar) {
    layout(matrix(c(2, 1), nrow=1), widths=c(10,1))
    opar <- par(mai=c(1, 0.5, 1, 0.1))
    on.exit(par(opar))
    on.exit(layout(1))
    image(1, seq(min(geo, na.rm=TRUE), max(geo, na.rm=TRUE), length=256),
      matrix(1:256, nrow=1), col=col,
      xaxt='n', xlab='', ylab='')

  }
  image(1:mx, 1:my, geo, main=main, col=col, ...)
  abline(h = 0.5 + seq(0, my, length=1+max(temp$Main.Row)))
  abline(v = 0.5 + seq(0, mx, length=1+max(temp$Main.Col)))
  invisible(x)
})



if (FALSE) {
  path <- "../inst/rppaTumorData"
  erk2 <- RPPA("ERK2.txt", path=path)
  summary(erk2)
  image(erk2)
  image(erk2, colorbar=TRUE)
  image(erk2, "Vol.Bkg", colorbar=TRUE)
  rm(path, erk2)
}

