\name{powercalc}
\alias{powercalc}
\title{ Power Calculations for a Model Fit to Dilution Series}
\description{
  This function estimates the power to detect a difference in the mean
  log concentration for two groups of samples  in a reverse-phase
  protein array experiment.
}
\usage{
powercalc(n, dilnFit, upper = 0.95, lower = 0.50, nrep = 1000, alpha = 0.05)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dilnFit}{A \code{\link{RPPAFit}} object representing the
    result of fitting a four-parameter logistic model}
  \item{n}{size of the sample to be drawn}
  \item{upper}{quantile of the concentration on the upper end of the curve}
  \item{lower}{quantile fo the concentraion on the lower end of the curve}
  \item{nrep}{the number of simulations to perform in order to estiamte
    the power}
  \item{alpha}{significance level at which the power is computed}
}
\details{
  The \code{powercalc} function estimates the power to detect a
  difference between the \code{upper} and \code{lower} quantiles of log
  concentration at the specified significance level \eqn{\alpha},
  assuming the samples come from two groups each of size \code{n}. The
  power calculation is based on a Wilcoxon rank sum test. The
  computation assumes that the only variability arises from the
  measurement error, as estimated by the residuals from the
  \code{\link{RPPAFit}}; thus, it will overestimate the power if
  there is additional biological variability within the two groups.
}
\value{
  Returns a real number, the power.
}
\references{KRC}
\author{Kevin R. Coombes <kcoombes@mdanderson.org>}
\seealso{  \code{\link{RPPAFit-class}} }
\examples{
path <- system.file("rppaCellData", package="SuperCurve")
akt <- RPPA("Akt.txt", path=path)
design <- RPPADesign(akt, grouping="blockSample",
                     controls=list("neg con", "pos con"))
fit.nls <- RPPAFit(akt, design, "Mean.Net")
# Warning: this takes a while!
powercalc(10, fit.nls, upper=0.75, lower=0.25)
}
\keyword{models}

